/* The MIT License
 *
 * Copyright (c) 2010 OTClient, https://github.com/edubart/otclient
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */


#include <prerequisites.h>
#include <core/configs.h>
#include <core/resources.h>

Configs g_configs;

bool Configs::load(const std::string& fileName)
{
    m_fileName = fileName;

    std::stringstream fin;
    if(!g_resources.loadFile(fileName, fin))
        return false;

    FML::Parser parser;
    if(parser.load(fin)) {
        FML::Node* doc = parser.getDocument();

        foreach(FML::Node* node, *doc)
            m_confsMap[node->tag()] = node->value();
    } else {
        flogError("ERROR: Malformed config file: %s", parser.getErrorMessage());
        return false;
    }

    return true;
}

void Configs::save()
{
    if(!m_fileName.empty()) {
        std::stringstream out;
        foreach(auto pair, m_confsMap) {
            out << pair.first << ": " << pair.second << std::endl;
        }
        g_resources.saveFile(m_fileName, out);
    }
}

